@@ -226,4 +226,12 @@ def GetOperationNameByNoun(operationNoun):
             if documents['entry_points'][operation]['noun'] == operationNoun:
                 return operation
 
-    return None
\ No newline at end of file
+    return None
+
+
+def GetOutputType(operationName):
+    
+    luna_config = Init()
+    with open(luna_config['MLproject']) as file:
+        documents = yaml.full_load(file)
+        return documents['entry_points'][operationName]['output']
\ No newline at end of file
